#
# spec file for package python-django-request
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
Name:           python-django-request
Version:        1.6.3
Release:        1.1
Summary:        Django statistics app
License:        BSD-2-Clause
URL:            https://github.com/django-request/django-request
Source:         https://github.com/django-request/django-request/archive/%{version}.tar.gz#/django-request-%{version}.tar.gz
# gh#django-request/django-request#241
Patch0:         set-timezone-for-day-tests.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-python-dateutil
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module python-dateutil}
# /SECTION
%python_subpackages

%description
django-request is a statistics module for django.
It stores requests in a database for admins to see,
it can also be used to get statistics on who is online etc.

%prep
%autosetup -p1 -n django-request-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=${PWD}
export DJANGO_SETTINGS_MODULE=tests.test_settings
%python_exec -m django test -v 2

%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.3:
  * Confirms support for Django 4.2.
  * Adds a missing migration with HTTP status codes.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.2:
  * Adds support for missing HTTP status codes: 103, 208, 226, 308, 428,
    429, 431, 451, and 511.
  * Confirms support for Python 3.11.
  * Confirms support for Django 4.1.
  * Don't ignore boosted htmx requests with ``REQUEST_IGNORE_AJAX``.
- drop python-django-request-no-mock.patch (upstream)
* Wed May 11 2022 pgajdos@suse.com
- version update to 1.6.1
  * Adds warning logging to middleware on invalid IP addresses in
    ``REMOTE_ADDR``.
  * Adds a missing migration to change ``help_text`` of ``Request.is_ajax``.
- do not require python-mock for build
- added patches
  fix https://github.com/django-request/django-request/issues/245
  + python-django-request-no-mock.patch
* Fri Feb 25 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.6.0:
  * Support for Django 1.11, 2.0, 2.1, 3.0, and 3.1 has been dropped.
  * Support for Python 2.7 and 3.4 has been dropped.
  * Adds htmx support to the REQUEST_IGNORE_AJAX setting.
  * Confirms support for Django 4.0.
  * Confirms support for Django 3.2.
  * Confirms support for Python 3.10.
  * Confirms support for Python 3.9.
- Drop six from {Build,}Requires.
- Add patch set-timezone-for-day-tests.patch:
  * Set overridden timezone.
* Sun Sep 13 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.5.6
* Wed Jul 21 2010 alexandre@exatati.com.br
- Update to 0.3.
* Mon Jun 28 2010 alexandre@exatati.com.br
- Update to 0.23;
- Spec file cleaned with spec-cleaner.
* Fri Jan 22 2010 alexandre@exatati.com.br
- Initial package (0.21) for openSUSE.
